# gco
A Python interface to the [gco](https://github.com/agoose77/gco-v3.0) library (modified for repackaging from [the original source](https://vision.cs.uwaterloo.ca/code/))

The exposed `GCoptimization<XXX>Graph` classes are available under the `gco` root namespace.

See the [research homepage](https://vision.cs.uwaterloo.ca/code/) for license and usage information.
